@@ -58,6 +58,7 @@
 #'  24 and a `cycle_size` equal to 86400 is equivalent to a `frequency` of
 #'  1.0 with `cycle_size` equal to 3600.
 #'
+#' @template case-weights-not-supported
 #'
 #' @references Doran, H. E., & Quilkey, J. J. (1972).
 #'   Harmonic analysis of seasonal data: some important properties.
@@ -67,15 +68,17 @@
 #'   The harmonic analysis of tidal model time series.
 #'   Advances in water resources, 12(3), 109-120.
 #'
-#' @examples
+#' @examplesIf rlang::is_installed("ggplot2")
 #' library(ggplot2, quietly = TRUE)
 #' library(dplyr)
 #'
 #' data(sunspot.year)
 #' sunspots <-
-#'   tibble(year = 1700:1988,
-#'          n_sunspot = sunspot.year,
-#'          type = "measured") %>%
+#'   tibble(
+#'     year = 1700:1988,
+#'     n_sunspot = sunspot.year,
+#'     type = "measured"
+#'   ) %>%
 #'   slice(1:75)
 #'
 #' # sunspots period is around 11 years, sample spacing is one year
@@ -86,9 +89,11 @@
 #'
 #' fit <- lm(n_sunspot ~ year_sin_1 + year_cos_1, data = dat)
 #'
-#' preds <- tibble(year = sunspots$year,
-#'                 n_sunspot = fit$fitted.values,
-#'                 type = 'predicted')
+#' preds <- tibble(
+#'   year = sunspots$year,
+#'   n_sunspot = fit$fitted.values,
+#'   type = "predicted"
+#' )
 #'
 #' bind_rows(sunspots, preds) %>%
 #'   ggplot(aes(x = year, y = n_sunspot, color = type)) +
@@ -100,34 +105,40 @@
 #'
 #' date_time <-
 #'   as.POSIXct(
-#'     paste0(rep(1959:1997, each = 12), '-', rep(1:12, length(1959:1997)), '-01'),
-#'     tz = 'UTC')
+#'     paste0(rep(1959:1997, each = 12), "-", rep(1:12, length(1959:1997)), "-01"),
+#'     tz = "UTC"
+#'   )
 #'
-#' carbon_dioxide <- tibble(date_time = date_time,
-#'                          co2 = as.numeric(co2),
-#'                          type = "measured")
+#' carbon_dioxide <- tibble(
+#'   date_time = date_time,
+#'   co2 = as.numeric(co2),
+#'   type = "measured"
+#' )
 #'
 #' # yearly co2 fluctuations
 #' dat <-
 #'   recipe(co2 ~ date_time,
-#'          data = carbon_dioxide) %>%
+#'     data = carbon_dioxide
+#'   ) %>%
 #'   step_mutate(date_time_num = as.numeric(date_time)) %>%
 #'   step_ns(date_time_num, deg_free = 3) %>%
 #'   step_harmonic(date_time, frequency = 1, cycle_size = 86400 * 365.24) %>%
 #'   prep() %>%
 #'   bake(new_data = NULL)
 #'
-#'  fit <- lm(co2 ~ date_time_num_ns_1 + date_time_num_ns_2 +
-#'                  date_time_num_ns_3 + date_time_sin_1 +
-#'                  date_time_cos_1, data = dat)
+#' fit <- lm(co2 ~ date_time_num_ns_1 + date_time_num_ns_2 +
+#'   date_time_num_ns_3 + date_time_sin_1 +
+#'   date_time_cos_1, data = dat)
 #'
-#'  preds <- tibble(date_time = date_time,
-#'                  co2 = fit$fitted.values,
-#'                  type = 'predicted')
+#' preds <- tibble(
+#'   date_time = date_time,
+#'   co2 = fit$fitted.values,
+#'   type = "predicted"
+#' )
 #'
-#'  bind_rows(carbon_dioxide, preds) %>%
-#'    ggplot(aes(x = date_time, y = co2, color = type)) +
-#'    geom_line()
+#' bind_rows(carbon_dioxide, preds) %>%
+#'   ggplot(aes(x = date_time, y = co2, color = type)) +
+#'   geom_line()
 step_harmonic <-
   function(recipe,
            ...,
@@ -140,15 +151,14 @@ step_harmonic <-
            columns = NULL,
            skip = FALSE,
            id = rand_id("harmonic")) {
-
     if (!all(is.numeric(cycle_size)) | all(is.na(cycle_size))) {
       rlang::abort("cycle_size must have at least one non-NA numeric value.")
     }
 
     if (!all(is.na(starting_val)) &
-        !all(is.numeric(starting_val)) &
-        !all(inherits(starting_val, 'Date')) &
-        !all(inherits(starting_val, 'POSIXt'))) {
+      !all(is.numeric(starting_val)) &
+      !all(inherits(starting_val, "Date")) &
+      !all(inherits(starting_val, "POSIXt"))) {
       rlang::abort("starting_val must be NA, numeric, Date or POSIXt")
     }
 
@@ -192,40 +202,46 @@ step_harmonic_new <-
 
 #' @export
 prep.step_harmonic <- function(x, training, info = NULL, ...) {
-
   col_names <- recipes_eval_select(x$terms, training, info)
   harmonic_data <- info[info$variable %in% col_names, ]
 
   # check input columns
-  if (any(harmonic_data$type != "date" & harmonic_data$type != "numeric"))
+  if (any(harmonic_data$type != "date" & harmonic_data$type != "numeric")) {
     rlang::abort(
       paste0(
         "All variables for `step_harmonic` should be either `Date` ",
         "`POSIXct` or `numeric` classes."
       )
     )
+  }
 
 
   # check cycle_size
-  if (length(x$cycle_size) == 1)
+  if (length(x$cycle_size) == 1) {
     cycle_sizes <- rep(x$cycle_size, length(col_names))
-  else if (length(x$cycle_size) == length(col_names))
+  } else if (length(x$cycle_size) == length(col_names)) {
     cycle_sizes <- x$cycle_size
-  else
-    rlang::abort(paste0("`cycle_size` must be length 1 or the same  ",
-                        "length as the input columns"))
+  } else {
+    rlang::abort(paste0(
+      "`cycle_size` must be length 1 or the same  ",
+      "length as the input columns"
+    ))
+  }
 
 
   # check starting_val
-  if (all(is.na(x$starting_val)))
+  if (all(is.na(x$starting_val))) {
     starting_vals <- rep(0.0, length(col_names))
-  else if (length(x$starting_val) == 1)
+  } else if (length(x$starting_val) == 1) {
     starting_vals <- rep(as.numeric(x$starting_val), length(col_names))
-  else if (length(x$starting_val) == length(col_names))
+  } else if (length(x$starting_val) == length(col_names)) {
     starting_vals <- x$starting_val
-  else
-    rlang::abort(paste0("`starting_val` must be length 1 or the same  ",
-                        "length as the input columns"))
+  } else {
+    rlang::abort(paste0(
+      "`starting_val` must be length 1 or the same  ",
+      "length as the input columns"
+    ))
+  }
 
   frequencies <- sort(unique(na.omit(x$frequency)))
 
@@ -252,9 +268,9 @@ sin_cos <- function(x,
                     frequency,
                     starting_val,
                     cycle_size) {
-
-  if (all(is.na(x)))
+  if (all(is.na(x))) {
     rlang::abort("variable must have at least one non-NA value")
+  }
 
   nc <- length(frequency)
   nr <- length(x)
@@ -263,13 +279,14 @@ sin_cos <- function(x,
   x <- x - as.numeric(starting_val)
 
   # cycles per unit
-  cycle <- 2.0 * (pi * (x / cycle_size));
+  cycle <- 2.0 * (pi * (x / cycle_size))
 
   m <- matrix(NA_real_,
-              ncol = nc * 2L,
-              nrow = nr)
+    ncol = nc * 2L,
+    nrow = nr
+  )
 
-  for(i in seq_along(frequency)) {
+  for (i in seq_along(frequency)) {
     m[, i] <- sin(cycle * frequency[i])
     m[, i + nc] <- cos(cycle * frequency[i])
   }
@@ -281,20 +298,23 @@ sin_cos <- function(x,
 
 #' @export
 bake.step_harmonic <- function(object, new_data, ...) {
-
   col_names <- names(object$starting_val)
+  check_new_data(col_names, object, new_data)
 
   # calculate sin and cos columns
   for (i in seq_along(col_names)) {
     col_name <- col_names[i]
     n_frequency <- length(object$frequency)
-    res <- sin_cos(as.numeric(new_data[[col_name]]),
-                   object$frequency,
-                   object$starting_val[i],
-                   object$cycle_size[i])
-    colnames(res) <- paste0(col_name,
-                            rep(c('_sin_', '_cos_'), each = n_frequency),
-                            1:n_frequency
+    res <- sin_cos(
+      as.numeric(new_data[[col_name]]),
+      object$frequency,
+      object$starting_val[i],
+      object$cycle_size[i]
+    )
+    colnames(res) <- paste0(
+      col_name,
+      rep(c("_sin_", "_cos_"), each = n_frequency),
+      1:n_frequency
     )
     res <- as_tibble(res)
     new_data <- bind_cols(new_data, res)
@@ -305,8 +325,7 @@ bake.step_harmonic <- function(object, new_data, ...) {
     new_data <-
       new_data[, !(colnames(new_data) %in% col_names), drop = FALSE]
   }
-
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
@@ -327,23 +346,28 @@ tidy.step_harmonic <- function(x, ...) {
     n_terms <- length(col_names)
 
     res <-
-      tibble(terms = rep(col_names, each = n_frequency * 2L),
-             starting_val = rep(unname(x$starting_val), each = n_frequency * 2L),
-             cycle_size = rep(unname(x$cycle_size), each = n_frequency * 2L),
-             frequency = rep(rep(unname(x$frequency), times = 2L), times = n_terms),
+      tibble(
+        terms = rep(col_names, each = n_frequency * 2L),
+        starting_val = rep(unname(x$starting_val), each = n_frequency * 2L),
+        cycle_size = rep(unname(x$cycle_size), each = n_frequency * 2L),
+        frequency = rep(rep(unname(x$frequency), times = 2L), times = n_terms),
       )
-    res$key <- paste0(res$terms,
-                      rep(rep(c('_sin_', '_cos_'), each = n_frequency),
-                          times = n_terms),
-                      res$frequency)
-
+    res$key <- paste0(
+      res$terms,
+      rep(rep(c("_sin_", "_cos_"), each = n_frequency),
+        times = n_terms
+      ),
+      res$frequency
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  starting_val = na_dbl,
-                  cycle_size = na_dbl,
-                  frequency = na_dbl,
-                  key = na_chr)
+    res <- tibble(
+      terms = term_names,
+      starting_val = na_dbl,
+      cycle_size = na_dbl,
+      frequency = na_dbl,
+      key = na_chr
+    )
   }
   res$id <- x$id
   res
