@@ -66,11 +66,13 @@
 #' for the variable loadings per component or `type = "variance"` for how
 #' much variance each component accounts for.
 #'
+#' @template case-weights-unsupervised
+#'
 #' @references Jolliffe, I. T. (2010). *Principal Component
 #'  Analysis*. Springer.
 #'
 #' @examples
-#' rec <- recipe( ~ ., data = USArrests)
+#' rec <- recipe(~., data = USArrests)
 #' pca_trans <- rec %>%
 #'   step_normalize(all_numeric()) %>%
 #'   step_pca(all_numeric(), num_comp = 3)
@@ -79,7 +81,8 @@
 #'
 #' rng <- extendrange(c(pca_data$PC1, pca_data$PC2))
 #' plot(pca_data$PC1, pca_data$PC2,
-#'      xlim = rng, ylim = rng)
+#'   xlim = rng, ylim = rng
+#' )
 #'
 #' with_thresh <- rec %>%
 #'   step_normalize(all_numeric()) %>%
@@ -93,7 +96,7 @@ step_pca <- function(recipe,
                      ...,
                      role = "predictor",
                      trained = FALSE,
-                     num_comp  = 5,
+                     num_comp = 5,
                      threshold = NA,
                      options = list(),
                      res = NULL,
@@ -102,7 +105,6 @@ step_pca <- function(recipe,
                      keep_original_cols = FALSE,
                      skip = FALSE,
                      id = rand_id("pca")) {
-
   if (!is_tune(threshold) & !is_varying(threshold)) {
     if (!is.na(threshold) && (threshold > 1 | threshold <= 0)) {
       rlang::abort("`threshold` should be on (0, 1].")
@@ -123,14 +125,15 @@ step_pca <- function(recipe,
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = NULL
     )
   )
 }
 
 step_pca_new <-
   function(terms, role, trained, num_comp, threshold, options, res, columns,
-           prefix,  keep_original_cols, skip, id) {
+           prefix, keep_original_cols, skip, id, case_weights) {
     step(
       subclass = "pca",
       terms = terms,
@@ -144,41 +147,53 @@ step_pca_new <-
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
 #' @export
 prep.step_pca <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
   check_type(training[, col_names])
 
-  if (x$num_comp > 0 && length(col_names) > 0) {
-    prc_call <-
-      expr(prcomp(
-        retx = FALSE,
-        center = FALSE,
-        scale. = FALSE,
-        tol = NULL
-      ))
-    if (length(x$options) > 0)
-      prc_call <- mod_call_args(prc_call, args = x$options)
+  wts <- get_case_weights(info, training)
+  were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
+  if (isFALSE(were_weights_used)) {
+    wts <- NULL
+  }
 
-    prc_call$x <- expr(training[, col_names, drop = FALSE])
-    prc_obj <- eval(prc_call)
+  if (x$num_comp > 0 && length(col_names) > 0) {
+    if (is.null(wts)) {
+      prc_call <-
+        expr(prcomp(
+          retx = FALSE,
+          center = FALSE,
+          scale. = FALSE,
+          tol = NULL
+        ))
+      if (length(x$options) > 0) {
+        prc_call <- mod_call_args(prc_call, args = x$options)
+      }
+
+      prc_call$x <- expr(training[, col_names, drop = FALSE])
+      prc_obj <- eval(prc_call)
+      ## decide on removing prc elements that aren't used in new projections
+      ## e.g. `sdev` etc.
+    } else {
+      prc_obj <- pca_wts(training[, col_names, drop = FALSE], wts = wts)
+    }
 
     x$num_comp <- min(x$num_comp, length(col_names))
     if (!is.na(x$threshold)) {
-      total_var <- sum(prc_obj$sdev ^ 2)
+      total_var <- sum(prc_obj$sdev^2)
       num_comp <-
-        which.max(cumsum(prc_obj$sdev ^ 2 / total_var) >= x$threshold)
-      if (length(num_comp) == 0)
+        which.max(cumsum(prc_obj$sdev^2 / total_var) >= x$threshold)
+      if (length(num_comp) == 0) {
         num_comp <- length(prc_obj$sdev)
+      }
       x$num_comp <- num_comp
     }
-    ## decide on removing prc elements that aren't used in new projections
-    ## e.g. `sdev` etc.
 
   } else {
     prc_obj <- NULL
@@ -196,15 +211,23 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
     prefix = x$prefix,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
 #' @export
 bake.step_pca <- function(object, new_data, ...) {
+  if (is.null(object$columns)) {
+    object$columns <- stats::setNames(nm = rownames(object$res$rotation))
+  }
+
   if (length(object$columns) > 0 && !all(is.na(object$res$rotation))) {
+    check_new_data(object$columns, object, new_data)
+
     pca_vars <- rownames(object$res$rotation)
-    comps <- predict(object$res, newdata = new_data[, pca_vars])
+    comps <- scale(new_data[, pca_vars], object$res$center, object$res$scale) %*%
+      object$res$rotation
     comps <- comps[, 1:object$num_comp, drop = FALSE]
     comps <- check_name(comps, new_data, object)
     new_data <- bind_cols(new_data, as_tibble(comps))
@@ -214,12 +237,16 @@ bake.step_pca <- function(object, new_data, ...) {
       new_data <- new_data[, !(colnames(new_data) %in% pca_vars), drop = FALSE]
     }
   }
-  as_tibble(new_data)
+  new_data
 }
 
 print.step_pca <-
   function(x, width = max(20, options()$width - 29), ...) {
     if (x$trained) {
+      if (is.null(x$columns)) {
+        x$columns <- stats::setNames(nm = rownames(x$res$rotation))
+      }
+
       if (length(x$columns) == 0 || all(is.na(x$res$rotation))) {
         title <- "No PCA components were extracted from "
         columns <- names(x$columns)
@@ -230,7 +257,8 @@ print.step_pca <-
     } else {
       title <- "PCA extraction with "
     }
-    print_step(columns, x$terms, x$trained, title, width)
+    print_step(columns, x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
@@ -244,21 +272,25 @@ pca_coefs <- function(x) {
     res$terms <- rep(unname(x$columns), npc)
     res <- as_tibble(res)[, c("terms", "value", "component")]
   } else {
-    res <- tibble::tibble(terms = unname(x$columns), value = rlang::na_dbl,
-                          component = rlang::na_chr)
+    res <- tibble::tibble(
+      terms = unname(x$columns), value = rlang::na_dbl,
+      component = rlang::na_chr
+    )
   }
   res
 }
 
 pca_variances <- function(x) {
   if (x$num_comp > 0 && length(x$columns) > 0) {
-    variances <- x$res$sdev ^ 2
+    variances <- x$res$sdev^2
     p <- length(variances)
     tot <- sum(variances)
-    y <- c(variances,
-           cumsum(variances),
-           variances / tot * 100,
-           cumsum(variances) / tot * 100)
+    y <- c(
+      variances,
+      cumsum(variances),
+      variances / tot * 100,
+      cumsum(variances) / tot * 100
+    )
     x <-
       rep(
         c(
@@ -270,9 +302,11 @@ pca_variances <- function(x) {
         each = p
       )
 
-    res <- tibble::tibble(terms = x,
-                          value = y,
-                          component = rep(1:p, 4))
+    res <- tibble::tibble(
+      terms = x,
+      value = y,
+      component = rep(1:p, 4)
+    )
   } else {
     res <- tibble::tibble(
       terms = unname(x$columns),
@@ -293,9 +327,11 @@ pca_variances <- function(x) {
 tidy.step_pca <- function(x, type = "coef", ...) {
   if (!is_trained(x)) {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_dbl,
-                  component  = na_chr)
+    res <- tibble(
+      terms = term_names,
+      value = na_dbl,
+      component = na_chr
+    )
   } else {
     type <- match.arg(type, c("coef", "variance"))
     if (type == "coef") {
