@@ -14,15 +14,18 @@
 #' @export
 #' @rdname step_percentile
 #'
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @template case-weights-unsupervised
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr) %>%
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
+#'
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'   data = biomass_tr
+#' ) %>%
 #'   step_percentile(carbon)
 #'
 #' prepped_rec <- prep(rec)
@@ -38,26 +41,26 @@ step_percentile <-
            role = NA,
            trained = FALSE,
            ref_dist = NULL,
-           options = list(probs = (0:100)/100),
+           options = list(probs = (0:100) / 100),
            skip = FALSE,
            id = rand_id("percentile")) {
-
-  add_step(
-    recipe,
-    step_percentile_new(
-      terms = enquos(...),
-      trained = trained,
-      role = role,
-      ref_dist = ref_dist,
-      options = options,
-      skip = skip,
-      id = id
+    add_step(
+      recipe,
+      step_percentile_new(
+        terms = enquos(...),
+        trained = trained,
+        role = role,
+        ref_dist = ref_dist,
+        options = options,
+        skip = skip,
+        id = id,
+        case_weights = NULL
+      )
     )
-  )
-}
+  }
 
 step_percentile_new <-
-  function(terms, role, trained, ref_dist, options, skip, id) {
+  function(terms, role, trained, ref_dist, options, skip, id, case_weights) {
     step(
       subclass = "percentile",
       terms = terms,
@@ -66,7 +69,8 @@ step_percentile_new <-
       ref_dist = ref_dist,
       options = options,
       skip = skip,
-      id = id
+      id = id,
+      case_weights = case_weights
     )
   }
 
@@ -74,11 +78,17 @@ step_percentile_new <-
 prep.step_percentile <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
 
+  wts <- get_case_weights(info, training)
+  were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
+  if (isFALSE(were_weights_used)) {
+    wts <- NULL
+  }
+
   ## We'll use the names later so make sure they are available
   x$options$names <- TRUE
 
   if (!any(names(x$options) == "probs")) {
-    x$options$probs <- (0:100)/100
+    x$options$probs <- (0:100) / 100
   } else {
     x$options$probs <- sort(unique(x$options$probs))
   }
@@ -86,6 +96,7 @@ prep.step_percentile <- function(x, training, info = NULL, ...) {
   ref_dist <- purrr::map(
     training[, col_names],
     get_train_pctl,
+    wts = wts,
     args = x$options
   )
 
@@ -96,37 +107,58 @@ prep.step_percentile <- function(x, training, info = NULL, ...) {
     ref_dist = ref_dist,
     options = x$options,
     skip = x$skip,
-    id = x$id
+    id = x$id,
+    case_weights = were_weights_used
   )
 }
 
-get_train_pctl <- function(x, args = NULL) {
-  res <- rlang::exec("quantile", x = x, !!!args)
+get_train_pctl <- function(x, wts, args = NULL) {
+  if (is.null(wts)) {
+    res <- rlang::exec("quantile", x = x, !!!args)
+  } else {
+    wts <- as.double(wts)
+    res <- rlang::exec("wrighted_quantile", x = x, wts = wts, !!!args)
+  }
+
   # Remove duplicate percentile values
   res[!duplicated(res)]
 }
 
+wrighted_quantile <- function(x, wts, probs, ...) {
+  order_x <- order(x)
+  x <- x[order_x]
+  wts <- wts[order_x]
+
+  wts_norm <- cumsum(wts) / sum(wts)
+  res <- purrr::map_dbl(probs, ~x[min(which(wts_norm >= .x))])
+
+  names(res) <- paste0(probs * 100, "%")
+  res
+}
+
 #' @export
 bake.step_percentile <- function(object, new_data, ...) {
   vars <- names(object$ref_dist)
+  check_new_data(vars, object, new_data)
 
   new_data[, vars] <-
     purrr::map2_dfc(new_data[, vars], object$ref_dist, pctl_by_approx)
 
-  tibble::as_tibble(new_data)
+  new_data
 }
 
 pctl_by_approx <- function(x, ref) {
   # In case duplicates were removed, get the percentiles from
   # the names of the reference object
   grid <- as.numeric(gsub("%$", "", names(ref)))
-  stats::approx(x = ref, y = grid, xout = x)$y/100
+  stats::approx(x = ref, y = grid, xout = x)$y / 100
 }
 
 print.step_percentile <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Percentile transformation on ", sep = "")
-    printer(x$terms, names(x$ref_dist), x$trained, width)
+    title <- "Percentile transformation on "
+    print_step(names(x$ref_dist), x$terms, x$trained, title, width,
+               case_weights = x$case_weights)
     invisible(x)
   }
 
@@ -143,8 +175,7 @@ tidy.step_percentile <- function(x, ...) {
     } else {
       res <- map_dfr(x$ref_dist, format_pctl, .id = "term")
     }
-  }
-  else {
+  } else {
     term_names <- sel2char(x$terms)
     res <-
       tibble(
