@@ -13,21 +13,20 @@
 #' \dontrun{
 #' recipes_pkg_check("recipes")
 #' }
-#' @importFrom rlang quos quo quo_squash
-#' @importFrom utils install.packages
 recipes_pkg_check <- function(pkg = NULL, ...) {
   good <- rep(TRUE, length(pkg))
-  for (i in seq(along = pkg)) {
+  for (i in seq(along.with = pkg)) {
     tested <- try(find.package(pkg[i]), silent = TRUE)
-    if (class(tested)[1] == "try-error")
+    if (class(tested)[1] == "try-error") {
       good[i] <- FALSE
+    }
   }
   if (any(!good)) {
     pkList <- paste(pkg[!good], collapse = ", ")
     msg <- paste0(
       sum(!good),
       ifelse(sum(!good) > 1, " packages are", " package is"),
-      " needed for this model and",
+      " needed for this step and",
       ifelse(sum(!good) > 1, " are", " is"),
       " not installed. (",
       pkList,
@@ -35,20 +34,19 @@ recipes_pkg_check <- function(pkg = NULL, ...) {
       "Start a clean R session then run: "
     )
     cat(msg)
-    
+
     install_opt <- quos(...)
     install_pkg <- pkg[!good]
-    if (length(install_pkg) > 1)
+    if (length(install_pkg) > 1) {
       inst_expr <-
-      quo(install.packages(c(!!!install_pkg),!!!install_opt))
-    else
+        quo(install.packages(c(!!!install_pkg), !!!install_opt))
+    } else {
       inst_expr <-
-      quo(install.packages(!!install_pkg,!!!install_opt))
+        quo(install.packages(!!install_pkg, !!!install_opt))
+    }
     pkg_str <- deparse(quo_squash(inst_expr))
     cat(pkg_str)
   }
-  
+
   invisible()
 }
-
-
