@@ -18,7 +18,9 @@ print_step <- function(tr_obj = NULL,
                        untr_obj = NULL,
                        trained = FALSE,
                        title = NULL,
-                       width = max(20, options()$width - 30)) {
+                       width = max(20, options()$width - 30),
+                       case_weights = NULL) {
+
   cat(title)
 
   if (trained) {
@@ -34,7 +36,16 @@ print_step <- function(tr_obj = NULL,
   cat(txt)
 
   if (trained) {
-    cat(" [trained]\n")
+    if (is.null(case_weights)) {
+      cat(" [trained]\n")
+    } else {
+      case_weights_ind <- ifelse(case_weights, "weighted", "ignored weights")
+      trained_txt <- paste(case_weights_ind, "trained", sep = ", ")
+      trained_txt <- paste0(" [", trained_txt, "]\n")
+      cat(trained_txt)
+    }
+
+
   } else {
     cat("\n")
   }
