@@ -4,14 +4,14 @@ library(dplyr)
 
 # ------------------------------------------------------------------------------
 
-iris_rec <- recipe( ~ ., data = iris)
+iris_rec <- recipe(~., data = iris)
 
 # ------------------------------------------------------------------------------
 
-test_that('basic usage', {
+test_that("basic usage", {
   rec <-
     iris_rec %>%
-    step_arrange(desc(Sepal.Length), 1/Petal.Length)
+    step_arrange(desc(Sepal.Length), 1 / Petal.Length)
 
   prepped <- prep(rec, training = iris %>% slice(1:75))
 
@@ -19,7 +19,7 @@ test_that('basic usage', {
     iris %>%
     as_tibble() %>%
     slice(1:75) %>%
-    dplyr::arrange(desc(Sepal.Length), 1/Petal.Length)
+    dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
 
   rec_train <- juice(prepped)
   expect_equal(dplyr_train, rec_train)
@@ -28,12 +28,12 @@ test_that('basic usage', {
     iris %>%
     as_tibble() %>%
     slice(76:150) %>%
-    dplyr::arrange(desc(Sepal.Length), 1/Petal.Length)
+    dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
   rec_test <- bake(prepped, iris %>% slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
 
-test_that('quasiquotation', {
+test_that("quasiquotation", {
   sort_vars <- c("Sepal.Length", "Petal.Length")
   sort_vars <- syms(sort_vars)
   rec_1 <-
@@ -50,10 +50,9 @@ test_that('quasiquotation', {
 
   rec_1_train <- juice(prepped_1)
   expect_equal(dplyr_train, rec_1_train)
-
 })
 
-test_that('no input', {
+test_that("no input", {
   no_inputs <-
     iris_rec %>%
     step_arrange() %>%
@@ -85,9 +84,8 @@ test_that("empty printing", {
   expect_snapshot(rec)
 })
 
-test_that('printing', {
+test_that("printing", {
   rec <- iris_rec %>% step_arrange(Sepal.Length)
-  expect_output(print(rec))
-  expect_output(prep(rec, training = iris, verbose = TRUE))
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
-
