@@ -1,18 +1,16 @@
 library(testthat)
-library(kernlab)
 library(recipes)
 
 
 set.seed(131)
-tr_dat <- matrix(rnorm(100*6), ncol = 6)
-te_dat <- matrix(rnorm(20*6), ncol = 6)
+tr_dat <- matrix(rnorm(100 * 6), ncol = 6)
+te_dat <- matrix(rnorm(20 * 6), ncol = 6)
 colnames(tr_dat) <- paste0("X", 1:6)
 colnames(te_dat) <- paste0("X", 1:6)
 
 rec <- recipe(X1 ~ ., data = tr_dat)
 
-test_that('correct kernel PCA values', {
-
+test_that("correct kernel PCA values", {
   skip_if_not_installed("kernlab")
 
   kpca_rec <- rec %>% step_kpca(X2, X3, X4, X5, X6, id = "")
@@ -22,9 +20,10 @@ test_that('correct kernel PCA values', {
   pca_pred <- bake(kpca_trained, new_data = te_dat, all_predictors())
   pca_pred <- as.matrix(pca_pred)
 
-  pca_exp <- kpca(as.matrix(tr_dat[, -1]),
-                  kernel = kpca_rec$steps[[1]]$options$kernel,
-                  kpar = kpca_rec$steps[[1]]$options$kpar)
+  pca_exp <- kernlab::kpca(as.matrix(tr_dat[, -1]),
+    kernel = kpca_rec$steps[[1]]$options$kernel,
+    kpar = kpca_rec$steps[[1]]$options$kpar
+  )
 
   pca_pred_exp <- kernlab::predict(pca_exp, te_dat[, -1])[, 1:kpca_trained$steps[[1]]$num_comp]
   colnames(pca_pred_exp) <- paste0("kPC", 1:kpca_trained$steps[[1]]$num_comp)
@@ -42,8 +41,7 @@ test_that('correct kernel PCA values', {
 })
 
 
-test_that('printing', {
-
+test_that("printing", {
   skip_if_not_installed("kernlab")
 
   skip_if(packageVersion("rlang") < "1.0.0")
@@ -52,11 +50,12 @@ test_that('printing', {
   )
 
   expect_snapshot(kpca_rec)
-  expect_snapshot(prep(kpca_rec, training = tr_dat, verbose = TRUE))
+  expect_snapshot(prep(kpca_rec))
 })
 
 
-test_that('No kPCA comps', {
+test_that("No kPCA comps", {
+  skip_if_not_installed("kernlab")
   suppressWarnings(
     pca_extract <- rec %>%
       step_kpca(X2, X3, X4, X5, X6, num_comp = 0, id = "") %>%
@@ -82,9 +81,7 @@ test_that('No kPCA comps', {
 })
 
 
-test_that('keep_original_cols works', {
-
-
+test_that("keep_original_cols works", {
   skip_if_not_installed("kernlab")
 
   kpca_rec <- rec %>%
@@ -96,14 +93,14 @@ test_that('keep_original_cols works', {
 
   expect_equal(
     colnames(pca_pred),
-    c("X2", "X3", "X4", "X5", "X6",
-      "kPC1", "kPC2", "kPC3", "kPC4", "kPC5")
+    c(
+      "X2", "X3", "X4", "X5", "X6",
+      "kPC1", "kPC2", "kPC3", "kPC4", "kPC5"
+    )
   )
-
 })
 
-test_that('can prep recipes with no keep_original_cols', {
-
+test_that("can prep recipes with no keep_original_cols", {
   skip_if_not_installed("kernlab")
 
   kpca_rec <- rec %>%
@@ -112,7 +109,7 @@ test_that('can prep recipes with no keep_original_cols', {
   kpca_rec$steps[[1]]$keep_original_cols <- NULL
 
   suppressWarnings(
-    kpca_trained <- prep(kpca_rec, training = tr_dat, verbose = FALSE),
+    kpca_trained <- prep(kpca_rec, training = tr_dat, verbose = FALSE)
   )
 
   expect_error(
@@ -162,3 +159,17 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  skip_if_not_installed("kernlab")
+
+  kpca_rec <- rec %>% step_kpca(X2, X3, X4, X5, X6) %>%
+    update_role(X2, X3, X4, X5, X6, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  kpca_trained <- prep(kpca_rec, training = tr_dat, verbose = FALSE)
+
+  expect_error(bake(kpca_trained, new_data = te_dat[, 1:3]),
+               class = "new_data_missing_column")
+})
